@@ -31,14 +31,18 @@ import getopt
 
 from mkm import ID
 
-cur = os.path.abspath(__file__)
-cur = os.path.dirname(cur)
-cur = os.path.dirname(cur)
-cur = os.path.dirname(cur)
-sys.path.insert(0, cur)
+path = os.path.abspath(__file__)
+path = os.path.dirname(path)
+path = os.path.dirname(path)
+path = os.path.dirname(path)
+sys.path.insert(0, path)
 
 from dimples.utils import Log
-from dimples.database import AccountDatabase
+from dimples.database import Storage
+
+from dimples.config import ConfigLoader
+from dimples.register.shared import GlobalVariable
+from dimples.register.shared import init_database
 from dimples.register.generate import generate
 from dimples.register.modify import modify
 
@@ -55,8 +59,8 @@ def show_help():
     print('    DIM account generate/modify')
     print('')
     print('usages:')
-    print('    %s [--root=<DIR>] generate' % cmd)
-    print('    %s [--root=<DIR>] modify <ID>' % cmd)
+    print('    %s [--config=<FILE>] generate' % cmd)
+    print('    %s [--config=<FILE>] modify <ID>' % cmd)
     print('    %s [-h|--help]' % cmd)
     print('')
     print('actions:')
@@ -64,43 +68,50 @@ def show_help():
     print('    modify <ID>     edit document with ID')
     print('')
     print('optional arguments:')
+    print('    --config        config file path (default: "/etc/dim/config.ini")')
     print('    --help, -h      show this help message and exit')
-    print('    --root          set root directory (default: "/var/.dim")')
-    print('    --public        set directory for meta & document')
-    print('    --private       set directory for private keys')
     print('')
 
 
 def main():
     try:
         opts, args = getopt.getopt(args=sys.argv[1:],
-                                   shortopts='hr:p:s:',
-                                   longopts=['help', 'root=', 'public=', 'private='])
+                                   shortopts='hf:',
+                                   longopts=['help', 'config='])
     except getopt.GetoptError:
         show_help()
         sys.exit(1)
     # check options
-    root_dir = None
-    pub_dir = None
-    pri_dir = None
+    ini_file = None
     for opt, arg in opts:
-        if opt == '--root':
-            root_dir = arg
-        elif opt == '--private':
-            pri_dir = arg
-        elif opt == '--public':
-            pub_dir = arg
+        if opt == '--config':
+            ini_file = arg
         else:
             show_help()
             sys.exit(0)
-    db = AccountDatabase(root=root_dir, public=pub_dir, private=pri_dir)
+    # check config filepath
+    if ini_file is None:
+        ini_file = '/etc/dim/config.ini'
+    if not Storage.exists(path=ini_file):
+        show_help()
+        print('')
+        print('!!! config file not exists: %s' % ini_file)
+        print('')
+        sys.exit(0)
+    # load config
+    config = ConfigLoader(file=ini_file).load()
+    # initializing
+    print('[DB] init with config: %s => %s' % (ini_file, config))
+    shared = GlobalVariable()
+    shared.config = config
+    init_database(shared=shared)
     # check actions
     if len(args) == 1 and args[0] == 'generate':
-        generate(db=db)
+        generate(db=shared.adb)
     elif len(args) == 2 and args[0] == 'modify':
         identifier = ID.parse(identifier=args[1])
         assert identifier is not None, 'ID error: %s' % args[1]
-        modify(identifier=identifier, db=db)
+        modify(identifier=identifier, db=shared.adb)
     else:
         show_help()
 
